package code;

import java.io.IOException;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.json.JSONException;

import com.sun.net.httpserver.Headers;
import com.sun.net.httpserver.HttpExchange;

public class Helper {

	public static void sendCors(HttpExchange exchange, int stato, String response) throws IOException {
		Headers headers = exchange.getResponseHeaders();
		headers.add("Access-Control-Allow-Origin", "*");// se non mettiamo *, viene errore CORS //http://localhost:3001/secured/domains
		headers.add("Access-Control-Allow-Methods", "GET, POST, OPTIONS");
		headers.add("Access-Control-Allow-Headers", "Content-Type,Authorization");
		if(response == null){
			exchange.sendResponseHeaders(stato, -1);
			return;
		}
		byte[] responseBytes = response.getBytes();
		exchange.sendResponseHeaders(200, responseBytes.length);
		OutputStream os = exchange.getResponseBody();
		os.write(responseBytes);
		os.close();
	}

	public static void sendCors(HttpExchange exchange, int stato) throws IOException {
		sendCors(exchange, stato, null);
	}

	public static void sendCors(HttpExchange exchange, String response) throws IOException {
		sendCors(exchange, 200, response);
	}

	public static String checkTokenGetUser(HttpExchange exchange) {
		String token = exchange.getRequestHeaders().get("Authorization").get(0).substring(7);// taglio bearer
		String[] tokSplit = token.split("[.]");
		if(tokSplit.length != 3) return null;
		String signature = tokSplit[2];
		try {
			return TokenHandler.verificaToken(token, signature);
		} catch (NoSuchAlgorithmException | IOException | JSONException e) {
			e.printStackTrace();
			return null;
		}
	}

	public static Map<String, Object> parseQuery(String query) throws UnsupportedEncodingException {
		if(query == null) throw new IllegalArgumentException("Query string can't be null");

		Map<String, Object> result = new HashMap<String, Object>();
		String pairs[] = query.split("[&]");
		for (String pair : pairs) {
			String param[] = pair.split("[=]");
			String key = null;
			String value = null;
			if (param.length > 0) {
				key = URLDecoder.decode(param[0], System.getProperty("file.encoding"));
			}

			if (param.length > 1) {
				value = URLDecoder.decode(param[1], System.getProperty("file.encoding"));
			}

			if (result.containsKey(key)) {
				Object obj = result.get(key);
				if (obj instanceof List<?>) {
					List<String> values = (List<String>) obj;
					values.add(value);
				} else if (obj instanceof String) {
					List<String> values = new ArrayList<String>();
					values.add((String) obj);
					values.add(value);
					result.put(key, values);
				}
			} else {
				result.put(key, value);
			}
		}
		return result;
	}

}
